Module compat

Module compat 

C API Compatibility Shims

Some CPython C API functions added in recent versions of Python are inherently safer to use than older C API constructs. This module exposes functions available on all Python versions that wrap the old C API on old Python versions and wrap the function directly on newer Python versions.

Structs

PyBytesWriterNeither Py_3_15 nor Py_LIMITED_API

Functions

PyBytesWriter_Create
PyBytesWriter_Discard
PyBytesWriter_Finish
PyBytesWriter_FinishWithSize
PyBytesWriter_GetData
PyBytesWriter_GetSize
PyBytesWriter_Resize
PyDict_GetItemRef
PyImport_AddModuleRef
PyIter_NextItem
PyList_Clear
PyList_Extend
PyList_GetItemRef
PyModule_Add
PyThreadState_GetUnchecked
PyWeakref_GetRef
Py_HashBuffer