C API Compatibility Shims
Some CPython C API functions added in recent versions of Python are inherently safer to use than older C API constructs. This module exposes functions available on all Python versions that wrap the old C API on old Python versions and wrap the function directly on newer Python versions.
Structs
- PyBytes
Writer Neither Py_3_15norPy_LIMITED_API
Functions
- PyBytes
Writer_ ⚠Create - PyBytes
Writer_ ⚠Discard - PyBytes
Writer_ ⚠Finish - PyBytes
Writer_ ⚠Finish With Size - PyBytes
Writer_ ⚠GetData - PyBytes
Writer_ ⚠GetSize - PyBytes
Writer_ ⚠Resize - PyDict_
GetItem ⚠Ref - PyImport_
AddModule ⚠Ref - PyIter_
Next ⚠Item - PyList_
Clear ⚠ - PyList_
Extend ⚠ - PyList_
GetItem ⚠Ref - PyModule_
Add ⚠ - PyThread
State_ ⚠GetUnchecked - PyWeakref_
GetRef ⚠ - Py_
Hash ⚠Buffer